@@ -710,7 +710,7 @@ gconf_engine_unref(GConfEngine* conf)
                       /* Don't set error because realistically this
                          doesn't matter to clients */
 #ifdef GCONF_ENABLE_DEBUG
-                      g_warning("Failure removing listener %u from the config server: %s",
+                      g_warning("Failure removing listener %u from the configuration server: %s",
                                 (guint)gcnxn->server_id,
                                 err->message);
 #endif
@@ -2280,9 +2280,9 @@ gconf_get_config_server(gboolean start_if_not_found, GError** err)
   return server; /* return what we have, NIL or not */
 }
 
-ConfigListener listener = CORBA_OBJECT_NIL;
+static ConfigListener listener = CORBA_OBJECT_NIL;
 
-void
+static void
 gconf_detach_config_server(void)
 {  
   CORBA_Environment ev;
@@ -2321,7 +2321,7 @@ gconf_detach_config_server(void)
  * gconf_debug_shutdown:
  * @void: 
  * 
- * Detach from the config server and release
+ * Detach from the configuration server and release
  * all related resources.
  *
  * Returns: 1 if an exception occurs, 0 otherwise.
@@ -2620,7 +2620,7 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
   if (*key != '/')
     {
       if (why_invalid != NULL)
-        *why_invalid = g_strdup(_("Must begin with a slash (/)"));
+        *why_invalid = g_strdup(_("Must begin with a slash '/'"));
       return FALSE;
     }
   
@@ -2642,9 +2642,9 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
               if (why_invalid != NULL)
                 {
                   if (*s == '/')
-                    *why_invalid = g_strdup(_("Can't have two slashes (/) in a row"));
+                    *why_invalid = g_strdup(_("Can't have two slashes '/' in a row"));
                   else
-                    *why_invalid = g_strdup(_("Can't have a period (.) right after a slash (/)"));
+                    *why_invalid = g_strdup(_("Can't have a period '.' right after a slash '/'"));
                 }
               return FALSE;
             }
@@ -2664,7 +2664,7 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
           if (c > 127)
             {
               if (why_invalid != NULL)
-                *why_invalid = g_strdup_printf (_("'\\%o' is not an ASCII character, so isn't allowed in key names"),
+                *why_invalid = g_strdup_printf (_("'\\%o' is not an ASCII character and thus isn't allowed in key names"),
                                                 (guint) c);
               return FALSE;
             }
@@ -2688,7 +2688,7 @@ gconf_valid_key      (const gchar* key, gchar** why_invalid)
   if (just_saw_slash)
     {
       if (why_invalid != NULL)
-        *why_invalid = g_strdup(_("Key/directory may not end with a slash (/)"));
+        *why_invalid = g_strdup(_("Key/directory may not end with a slash '/'"));
       return FALSE;
     }
   else
@@ -3059,7 +3059,7 @@ gconf_shutdown_daemon (GError** err)
   if (ev._major != CORBA_NO_EXCEPTION)
     {
       if (err)
-        *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down config server: %s"),
+        *err = gconf_error_new (GCONF_ERROR_FAILED, _("Failure shutting down configuration server: %s"),
                                 CORBA_exception_id (&ev));
 
       CORBA_exception_free(&ev);
@@ -3182,7 +3182,7 @@ gconf_engine_get_string(GConfEngine* conf, const gchar* key,
   val = gconf_engine_get (conf, key, err);
 
   if (val == NULL)
-    return deflt ? g_strdup(deflt) : NULL;
+    return g_strdup(deflt);
   else
     {
       gchar* retval;
@@ -3193,7 +3193,7 @@ gconf_engine_get_string(GConfEngine* conf, const gchar* key,
             *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH, _("Expected string, got %s"),
                                     gconf_value_type_to_string(val->type));
           gconf_value_free(val);
-          return deflt ? g_strdup(deflt) : NULL;
+          return g_strdup(deflt);
         }
 
       retval = gconf_value_steal_string (val);
